==> zen-cart-v1.2.0-l10n-jp-1.zip: zen-cart-v1.2.0-l10n-jp-1/admin/includes/languages/japanese/product.php <==
<?php
//
// +----------------------------------------------------------------------+
// |zen-cart Open Source E-commerce                                       |
// +----------------------------------------------------------------------+
// | Copyright (c) 2004 The zen-cart developers                           |
// |                                                                      |
// | http://www.zen-cart.com/index.php                                    |
// |                                                                      |
// | Portions Copyright (c) 2003 osCommerce                               |
// +----------------------------------------------------------------------+
// | This source file is subject to version 2.0 of the GPL license,       |
// | that is bundled with this package in the file LICENSE, and is        |
// | available through the world-wide-web at the following url:           |
// | http://www.zen-cart.com/license/2_0.txt.                             |
// | If you did not receive a copy of the zen-cart license and are unable |
// | to obtain it through the world-wide-web, please send a note to       |
// | license@zen-cart.com so we can mail you a copy immediately.          |
// +----------------------------------------------------------------------+
//  $Id: product.php,v 1.3 2004/11/20 07:23:11 shidairiki Exp $
//

define('HEADING_TITLE', 'ƥꡦ');
define('HEADING_TITLE_GOTO', ':');

define('TABLE_HEADING_ID', 'ID');
define('TABLE_HEADING_CATEGORIES_PRODUCTS', 'ƥꡦ');
define('TABLE_HEADING_CATEGORIES_SORT_ORDER', '');

define('TABLE_HEADING_PRICE','/̲/');
define('TABLE_HEADING_QUANTITY','');

define('TABLE_HEADING_ACTION', '');
define('TABLE_HEADING_STATUS', 'ơ');

define('TEXT_CATEGORIES', 'ƥ:');
define('TEXT_SUBCATEGORIES', '֥ƥ:');
define('TEXT_PRODUCTS', ':');
define('TEXT_PRODUCTS_PRICE_INFO', ':');
define('TEXT_PRODUCTS_TAX_CLASS', 'Ǽ:');
define('TEXT_PRODUCTS_AVERAGE_RATING', 'ʿ:');
define('TEXT_PRODUCTS_QUANTITY_INFO', ':');
define('TEXT_DATE_ADDED', 'Ͽ:');
define('TEXT_DATE_AVAILABLE', '󶡲ǽ:');
define('TEXT_LAST_MODIFIED', ':');
define('TEXT_IMAGE_NONEXISTENT', '᡼ʤ');
define('TEXT_NO_CHILD_CATEGORIES_OR_PRODUCTS', 'Υ٥˿ƥ꤫ʤɲäƤ.');
define('TEXT_PRODUCT_MORE_INFORMATION', '˾ܺ٤ʾˤʤˤϡξʤ <a href="http://%s" target="blank">Webڡ</a> ء');
define('TEXT_PRODUCT_DATE_ADDED', 'åפؤΤξʤϿ %');
define('TEXT_PRODUCT_DATE_AVAILABLE', 'ξʤ󶡲ǽ %');

define('TEXT_EDIT_INTRO', 'ɬפѹԤäƤ');
define('TEXT_EDIT_CATEGORIES_ID', 'ƥID:');
define('TEXT_EDIT_CATEGORIES_NAME', 'ƥ̾:');
define('TEXT_EDIT_CATEGORIES_IMAGE', 'ƥ:');
define('TEXT_EDIT_SORT_ORDER', 'Ƚ:');

define('TEXT_INFO_COPY_TO_INTRO', 'ξʤ򥳥ԡƥǤ');
define('TEXT_INFO_CURRENT_CATEGORIES', 'ߤΥƥ: ');

define('TEXT_INFO_HEADING_NEW_CATEGORY', 'ƥ');
define('TEXT_INFO_HEADING_EDIT_CATEGORY', 'ƥԽ');
define('TEXT_INFO_HEADING_DELETE_CATEGORY', 'ƥ');
define('TEXT_INFO_HEADING_MOVE_CATEGORY', 'ƥư');
define('TEXT_INFO_HEADING_DELETE_PRODUCT', 'ʤ');
define('TEXT_INFO_HEADING_MOVE_PRODUCT', 'ʤư');
define('TEXT_INFO_HEADING_COPY_TO', 'ԡ');

define('TEXT_DELETE_CATEGORY_INTRO', 'Υƥ˺ޤ?');
define('TEXT_DELETE_PRODUCT_INTRO', 'ξʤʵפ˺ޤ?');

define('TEXT_DELETE_WARNING_CHILDS', '<b>ٹ:</b> Υƥˤ % Ĥ ()ƥ꤬󥯤Ƥޤ!');
define('TEXT_DELETE_WARNING_PRODUCTS', '<b>ٹ:</b> Υƥˤ % Ĥξʤ󥯤Ƥޤ!');

define('TEXT_MOVE_PRODUCTS_INTRO', ' <b>%s</b> ưƥǤ');
define('TEXT_MOVE_CATEGORIES_INTRO', 'ƥ <b>%s</b> ưƥǤ');
define('TEXT_MOVE', 'Move <b>%s</b> ư:');

define('TEXT_NEW_CATEGORY_INTRO', 'ƥˤĤƤξϤƤ');
define('TEXT_CATEGORIES_NAME', 'ƥ̾:');
define('TEXT_CATEGORIES_IMAGE', 'ƥ:');
define('TEXT_SORT_ORDER', 'Ƚ:');

define('TEXT_PRODUCTS_STATUS', 'ʥơ:');
define('TEXT_PRODUCTS_VIRTUAL', '뾦l:');
define('TEXT_PRODUCTS_IS_ALWAYS_FREE_SHIPPING', '̵:');
define('TEXT_PRODUCTS_QTY_BOX_STATUS', 'ʤοɽ:');
define('TEXT_PRODUCTS_DATE_AVAILABLE', '󶡲ǽ:');
define('TEXT_PRODUCT_AVAILABLE', '߸ˤ');
define('TEXT_PRODUCT_NOT_AVAILABLE', '߸ڤ');
define('TEXT_PRODUCT_IS_VIRTUAL', 'Ϥ轻򥹥å');
define('TEXT_PRODUCT_NOT_VIRTUAL', '轻꤬ɬ');
define('TEXT_PRODUCT_IS_ALWAYS_FREE_SHIPPING', 'Ϥ̵');
define('TEXT_PRODUCT_NOT_ALWAYS_FREE_SHIPPING', '̾Ŭ');
define('TEXT_PRODUCTS_SORT_ORDER', 'Ƚ:');

define('TEXT_PRODUCTS_QTY_BOX_STATUS_ON', 'Ϥɽ');
define('TEXT_PRODUCTS_QTY_BOX_STATUS_OFF', 'ɽ');

define('TEXT_PRODUCTS_MANUFACTURER', 'ʥ᡼:');
define('TEXT_PRODUCTS_NAME', '̾:');
define('TEXT_PRODUCTS_DESCRIPTION', ':');
define('TEXT_PRODUCTS_QUANTITY', 'ʿ:');
define('TEXT_PRODUCTS_MODEL', 'ʷl:');
define('TEXT_PRODUCTS_IMAGE', 'ʲ:');
define('TEXT_PRODUCTS_IMAGE_DIR', 'åץǥ쥯ȥ:');
define('TEXT_PRODUCTS_URL', 'URL:');
define('TEXT_PRODUCTS_URL_WITHOUT_HTTP', '<small>(http://̵ǵ)</small>');
define('TEXT_PRODUCTS_PRICE_NET', 'ʲ (ͥå):');
define('TEXT_PRODUCTS_PRICE_GROSS', 'ʲ ():');
define('TEXT_PRODUCTS_WEIGHT', 'ʽ:');

define('EMPTY_CATEGORY', 'Υƥ');

define('TEXT_HOW_TO_COPY', 'ԡˡ:');
define('TEXT_COPY_AS_LINK', 'ʤ');
define('TEXT_COPY_AS_DUPLICATE', 'ʤʣ');

define('ERROR_CANNOT_LINK_TO_SAME_CATEGORY', '顼: Ʊƥξʤϥ󥯤Ǥޤ');
define('ERROR_CATALOG_IMAGE_DIRECTORY_NOT_WRITEABLE', '顼: ʤβǥ쥯ȥ꤬񤭹ԲĤǤ: ' . DIR_FS_CATALOG_IMAGES);
define('ERROR_CATALOG_IMAGE_DIRECTORY_DOES_NOT_EXIST', '顼: ʤβǥ쥯ȥ꤬¸ߤޤ: ' . DIR_FS_CATALOG_IMAGES);
define('ERROR_CANNOT_MOVE_CATEGORY_TO_PARENT', '顼: ƥϥ֥ƥˤϰưǤޤ');

// Products and Attribute Copy Options
  define('TEXT_COPY_ATTRIBUTES_ONLY','ʤʣ˻');
  define('TEXT_COPY_ATTRIBUTES','°ʣʤ˥ԡޤ?');
  define('TEXT_COPY_ATTRIBUTES_YES','Ϥ');
  define('TEXT_COPY_ATTRIBUTES_NO','');

  define('TEXT_INFO_CURRENT_PRODUCT', 'ߤξ: ');
  define('TABLE_HEADING_MODEL', '');

  define('TEXT_INFO_HEADING_ATTRIBUTE_FEATURES','ID# °ѹ ');
  define('TEXT_INFO_ATTRIBUTES_FEATURES_DELETE','<strong></strong> °::<br />');
  define('TEXT_INFO_ATTRIBUTES_FEATURES_COPY_TO','ξʤ°¾ξʤޤϥƥΤ˥ԡ:<br />');

  define('TEXT_INFO_ATTRIBUTES_FEATURES_COPY_TO_PRODUCT','ξʤ°̤ <strong></strong> ˥ԡ:<br />');
  define('TEXT_INFO_ATTRIBUTES_FEATURES_COPY_TO_CATEGORY','ξʤ°̤ <strong>ƥ</strong> ˥ԡ:<br />');

  define('TEXT_COPY_ATTRIBUTES_CONDITIONS','<strong>Ǥˤ뾦°ɤΤ褦˰ޤ?</strong>');
  define('TEXT_COPY_ATTRIBUTES_DELETE','ǽ<strong></strong>°򥳥ԡ');
  define('TEXT_COPY_ATTRIBUTES_UPDATE','ꡦʤ<strong></strong>Τä');
  define('TEXT_COPY_ATTRIBUTES_IGNORE','<strong>̵</strong>ƿ°äΤ');

  define('SUCCESS_ATTRIBUTES_DELETED','°Ϻޤ');
  define('SUCCESS_ATTRIBUTES_UPDATE','°Ϲޤ');

  define('ICON_ATTRIBUTES','°(Attribute Features)');

  define('TEXT_CATEGORIES_IMAGE_DIR','åץǥ쥯ȥ:');

  define('TEXT_VIRTUAL_PREVIEW','ٹ: ξʤϥޡѤ - ̵轻Ϥ򥹥å');
  define('TEXT_VIRTUAL_EDIT','ٹ: ξʤϥޡѤ - ̵轻Ϥ򥹥å');
  define('TEXT_FREE_SHIPPING_PREVIEW','ٹ: ξʤϥޡѤ - ̵轻Ϥɬ');
  define('TEXT_FREE_SHIPPING_EDIT','ٹ: ξʤϥޡѤ - ̵轻Ϥɬ');

  define('TEXT_PRODUCTS_QTY_BOX_STATUS_PREVIEW','ٹ: ɽ1');
  define('TEXT_PRODUCTS_QTY_BOX_STATUS_EDIT','ٹ: ɽ1');

  define('TEXT_PRODUCT_OPTIONS', '<strong>:</strong>');
  define('TEXT_PRODUCT_WEIGHT_UNIT','lbs');
  define('TEXT_PRODUCTS_ATTRIBUTES_INFO','°(Attribute Features):');
  define('TEXT_PRODUCT_ATTRIBUTES_DOWNLOADS','ɾ: ');

  define('TEXT_PRODUCTS_PRICED_BY_ATTRIBUTES','°ˤ:');
  define('TEXT_PRODUCT_IS_PRICED_BY_ATTRIBUTE','Ϥ');
  define('TEXT_PRODUCT_NOT_PRICED_BY_ATTRIBUTE','');
  define('TEXT_PRODUCTS_PRICED_BY_ATTRIBUTES_PREVIEW','**ɽʤϺǤ㤤롼°βʤޤ(Display price will include lowest group attributes prices plus price)');
  define('TEXT_PRODUCTS_PRICED_BY_ATTRIBUTES_EDIT','**ɽʤϺǤ㤤롼°βʤޤ(Display price will include lowest group attributes prices plus price)');

  define('TEXT_PRODUCTS_QUANTITY_MIN_RETAIL','ʤκǾ:');
  define('TEXT_PRODUCTS_QUANTITY_UNITS_RETAIL','ʤοñ:');
  define('TEXT_PRODUCTS_QUANTITY_MAX_RETAIL','ʤκ:');

  define('TEXT_PRODUCTS_QUANTITY_MAX_RETAIL_EDIT','0 = ̵¡1 = ɽ');

  define('TEXT_PRODUCTS_MIXED','Ǿ/ñ̥ߥå:');

  define('TEXT_PRODUCT_IS_FREE','̵:');
  define('TEXT_PRODUCTS_IS_FREE_PREVIEW','*̵ȥޡ줿');
  define('TEXT_PRODUCTS_IS_FREE_EDIT','*̵ȥޡ줿');

  define('TEXT_PRODUCT_IS_CALL','ʤ䤤碌:');
  define('TEXT_PRODUCTS_IS_CALL_PREVIEW','*ʤ䤤碌ȥޡ줿');
  define('TEXT_PRODUCTS_IS_CALL_EDIT','*ʤ䤤碌ȥޡ줿');

  define('TEXT_ATTRIBUTE_COPY_SKIPPING','<strong>°򥹥å </strong>');
  define('TEXT_ATTRIBUTE_COPY_INSERTING','<strong>°ʲ </strong>');
  define('TEXT_ATTRIBUTE_COPY_UPDATING','<strong>°ʲ鹹 </strong>');
?>

==> zen-cart-v1.3.0.2-l10n-jp-1.zip: zen-cart-v1.3.0.2-l10n-jp-1/admin/includes/languages/japanese/product.php <==
<?php
//
// +----------------------------------------------------------------------+
// |zen-cart Open Source E-commerce                                       |
// +----------------------------------------------------------------------+
// | Copyright (c) 2004 The zen-cart developers                           |
// |                                                                      |
// | http://www.zen-cart.com/index.php                                    |
// |                                                                      |
// | Portions Copyright (c) 2003 osCommerce                               |
// +----------------------------------------------------------------------+
// | This source file is subject to version 2.0 of the GPL license,       |
// | that is bundled with this package in the file LICENSE, and is        |
// | available through the world-wide-web at the following url:           |
// | http://www.zen-cart.com/license/2_0.txt.                             |
// | If you did not receive a copy of the zen-cart license and are unable |
// | to obtain it through the world-wide-web, please send a note to       |
// | license@zen-cart.com so we can mail you a copy immediately.          |
// +----------------------------------------------------------------------+
//  $Id: product.php 2830 2006-01-10 17:13:18Z birdbrain $
//

define('HEADING_TITLE', 'ƥꡦ');
define('HEADING_TITLE_GOTO', ':');

define('TABLE_HEADING_ID', 'ID');
define('TABLE_HEADING_CATEGORIES_PRODUCTS', 'ƥꡦ');
define('TABLE_HEADING_CATEGORIES_SORT_ORDER', '');

define('TABLE_HEADING_PRICE','/̲/');
define('TABLE_HEADING_QUANTITY','');

define('TABLE_HEADING_ACTION', '');
define('TABLE_HEADING_STATUS', 'ơ');

define('TEXT_CATEGORIES', 'ƥ:');
define('TEXT_SUBCATEGORIES', '֥ƥ:');
define('TEXT_PRODUCTS', ':');
define('TEXT_PRODUCTS_PRICE_INFO', ':');
define('TEXT_PRODUCTS_TAX_CLASS', 'Ǽ:');
define('TEXT_PRODUCTS_AVERAGE_RATING', 'ʿ:');
define('TEXT_PRODUCTS_QUANTITY_INFO', ':');
define('TEXT_DATE_ADDED', 'Ͽ:');
define('TEXT_DATE_AVAILABLE', '󶡲ǽ:');
define('TEXT_LAST_MODIFIED', ':');
define('TEXT_IMAGE_NONEXISTENT', '᡼ʤ');
define('TEXT_NO_CHILD_CATEGORIES_OR_PRODUCTS', 'Υ٥˿ƥ꤫ʤɲäƤ');
define('TEXT_PRODUCT_MORE_INFORMATION', '˾ܺ٤ʾˤʤˤϡξʤ <a href="http://%s" target="blank">Webڡ</a> ء');
define('TEXT_PRODUCT_DATE_ADDED', 'åפؤΤξʤϿ %s');
define('TEXT_PRODUCT_DATE_AVAILABLE', 'ξʤ󶡲ǽ %s');

define('TEXT_EDIT_INTRO', 'ɬפѹԤäƤ');
define('TEXT_EDIT_CATEGORIES_ID', 'ƥID:');
define('TEXT_EDIT_CATEGORIES_NAME', 'ƥ̾:');
define('TEXT_EDIT_CATEGORIES_IMAGE', 'ƥ:');
define('TEXT_EDIT_SORT_ORDER', 'Ƚ:');

define('TEXT_INFO_COPY_TO_INTRO', 'ξʤ򥳥ԡƥǤ');
define('TEXT_INFO_CURRENT_CATEGORIES', 'ߤΥƥ: ');

define('TEXT_INFO_HEADING_NEW_CATEGORY', 'ƥ');
define('TEXT_INFO_HEADING_EDIT_CATEGORY', 'ƥԽ');
define('TEXT_INFO_HEADING_DELETE_CATEGORY', 'ƥ');
define('TEXT_INFO_HEADING_MOVE_CATEGORY', 'ƥư');
define('TEXT_INFO_HEADING_DELETE_PRODUCT', 'ʤ');
define('TEXT_INFO_HEADING_MOVE_PRODUCT', 'ʤư');
define('TEXT_INFO_HEADING_COPY_TO', 'ԡ');

define('TEXT_DELETE_CATEGORY_INTRO', 'Υƥ˺ޤ?');
define('TEXT_DELETE_PRODUCT_INTRO', 'ξʤʵפ˺ޤ?');

define('TEXT_DELETE_WARNING_CHILDS', '<b>ٹ:</b> Υƥˤ %s Ĥ ()ƥ꤬󥯤Ƥޤ!');
define('TEXT_DELETE_WARNING_PRODUCTS', '<b>ٹ:</b> Υƥˤ %s Ĥξʤ󥯤Ƥޤ!');

define('TEXT_MOVE_PRODUCTS_INTRO', ' <b>%s</b> ưƥǤ');
define('TEXT_MOVE_CATEGORIES_INTRO', 'ƥ <b>%s</b> ưƥǤ');
define('TEXT_MOVE', 'Move <b>%s</b> ư:');

define('TEXT_NEW_CATEGORY_INTRO', 'ƥˤĤƤξϤƤ');
define('TEXT_CATEGORIES_NAME', 'ƥ̾:');
define('TEXT_CATEGORIES_IMAGE', 'ƥ:');
define('TEXT_SORT_ORDER', 'Ƚ:');

define('TEXT_PRODUCTS_STATUS', 'ʥơ:');
define('TEXT_PRODUCTS_VIRTUAL', '뾦l:');
define('TEXT_PRODUCTS_IS_ALWAYS_FREE_SHIPPING', '̵:');
define('TEXT_PRODUCTS_QTY_BOX_STATUS', 'ʤοɽ:');
define('TEXT_PRODUCTS_DATE_AVAILABLE', '󶡲ǽ:');
define('TEXT_PRODUCT_AVAILABLE', '߸ˤ');
define('TEXT_PRODUCT_NOT_AVAILABLE', '߸ڤ');
define('TEXT_PRODUCT_IS_VIRTUAL', 'Ϥ轻򥹥å');
define('TEXT_PRODUCT_NOT_VIRTUAL', '轻꤬ɬ');
define('TEXT_PRODUCT_IS_ALWAYS_FREE_SHIPPING', 'Ϥ̵');
define('TEXT_PRODUCT_NOT_ALWAYS_FREE_SHIPPING', '̾Ŭ');
define('TEXT_PRODUCT_SPECIAL_ALWAYS_FREE_SHIPPING', '褬ɬפü쾦/ɾ');//Special, Product/Download Combo Requires a Shipping Address
define('TEXT_PRODUCTS_SORT_ORDER', 'Ƚ:');

define('TEXT_PRODUCTS_QTY_BOX_STATUS_ON', 'Ϥɽ');
define('TEXT_PRODUCTS_QTY_BOX_STATUS_OFF', 'ɽ');

define('TEXT_PRODUCTS_MANUFACTURER', 'ʥ᡼:');
define('TEXT_PRODUCTS_NAME', '̾:');
define('TEXT_PRODUCTS_DESCRIPTION', ':');
define('TEXT_PRODUCTS_QUANTITY', 'ʿ:');
define('TEXT_PRODUCTS_MODEL', 'ʷl:');
define('TEXT_PRODUCTS_IMAGE', 'ʲ:');
define('TEXT_PRODUCTS_IMAGE_DIR', 'åץǥ쥯ȥ:');
define('TEXT_PRODUCTS_URL', 'URL:');
define('TEXT_PRODUCTS_URL_WITHOUT_HTTP', '<small>(http://̵ǵ)</small>');
define('TEXT_PRODUCTS_PRICE_NET', 'ʲ (ͥå):');
define('TEXT_PRODUCTS_PRICE_GROSS', 'ʲ ():');
define('TEXT_PRODUCTS_WEIGHT', 'ʽ:');

define('EMPTY_CATEGORY', 'Υƥ');

define('TEXT_HOW_TO_COPY', 'ԡˡ:');
define('TEXT_COPY_AS_LINK', 'ʤ');
define('TEXT_COPY_AS_DUPLICATE', 'ʤʣ');


// Products and Attribute Copy Options
  define('TEXT_COPY_ATTRIBUTES_ONLY','ʤʣ˻');
  define('TEXT_COPY_ATTRIBUTES','°ʣʤ˥ԡޤ?');
  define('TEXT_COPY_ATTRIBUTES_YES','Ϥ');
  define('TEXT_COPY_ATTRIBUTES_NO','');

// Products and Discount Copy Options
  define('TEXT_COPY_DISCOUNTS_ONLY','ʣʤˤΤ߳ŬѤޤ');
//Only used for Duplicate Products with Discounts ...
  define('TEXT_COPY_DISCOUNTS','ŬѤΤ˥ԡʤʣޤ');
//Copy Product Discounts to Duplicate?'
  define('TEXT_COPY_DISCOUNTS_YES','Ϥ');
  define('TEXT_COPY_DISCOUNTS_NO','');

  define('TEXT_INFO_CURRENT_PRODUCT', 'ߤξ: ');
  define('TABLE_HEADING_MODEL', '');

  define('TEXT_INFO_HEADING_ATTRIBUTE_FEATURES','ID# °ѹ ');
  define('TEXT_INFO_ATTRIBUTES_FEATURES_DELETE','<strong></strong> °::<br />');
  define('TEXT_INFO_ATTRIBUTES_FEATURES_COPY_TO','ξʤ°¾ξʤޤϥƥΤ˥ԡ:<br />');

  define('TEXT_INFO_ATTRIBUTES_FEATURES_COPY_TO_PRODUCT','ξʤ°̤ <strong></strong> ˥ԡ:<br />');
  define('TEXT_INFO_ATTRIBUTES_FEATURES_COPY_TO_CATEGORY','ξʤ°̤ <strong>ƥ</strong> ˥ԡ:<br />');

  define('TEXT_COPY_ATTRIBUTES_CONDITIONS','<strong>Ǥˤ뾦°ɤΤ褦˰ޤ?</strong>');
  define('TEXT_COPY_ATTRIBUTES_DELETE','ǽ<strong></strong>°򥳥ԡ');
  define('TEXT_COPY_ATTRIBUTES_UPDATE','ꡦʤ<strong></strong>Τä');
  define('TEXT_COPY_ATTRIBUTES_IGNORE','<strong>̵</strong>ƿ°äΤ');

  define('SUCCESS_ATTRIBUTES_DELETED','°Ϻޤ');
  define('SUCCESS_ATTRIBUTES_UPDATE','°Ϲޤ');

  define('ICON_ATTRIBUTES','°(Attribute Features)');

  define('TEXT_CATEGORIES_IMAGE_DIR','åץǥ쥯ȥ:');

  define('TEXT_PRODUCTS_QTY_BOX_STATUS_PREVIEW','ٹ: ɽ1');
  define('TEXT_PRODUCTS_QTY_BOX_STATUS_EDIT','ٹ: ɽ1');

  define('TEXT_PRODUCT_OPTIONS', '<strong>:</strong>');
  define('TEXT_PRODUCTS_ATTRIBUTES_INFO','°(Attribute Features):');
  define('TEXT_PRODUCT_ATTRIBUTES_DOWNLOADS','ɾ: ');

  define('TEXT_PRODUCTS_PRICED_BY_ATTRIBUTES','°ˤ:');
  define('TEXT_PRODUCT_IS_PRICED_BY_ATTRIBUTE','Ϥ');
  define('TEXT_PRODUCT_NOT_PRICED_BY_ATTRIBUTE','');
  define('TEXT_PRODUCTS_PRICED_BY_ATTRIBUTES_PREVIEW','**ɽʤϺǤ㤤롼°βʤޤ(Display price will include lowest group attributes prices plus price)');
  define('TEXT_PRODUCTS_PRICED_BY_ATTRIBUTES_EDIT','**ɽʤϺǤ㤤롼°βʤޤ(Display price will include lowest group attributes prices plus price)');

  define('TEXT_PRODUCTS_QUANTITY_MIN_RETAIL','ʤκǾ:');
  define('TEXT_PRODUCTS_QUANTITY_UNITS_RETAIL','ʤοñ:');
  define('TEXT_PRODUCTS_QUANTITY_MAX_RETAIL','ʤκ:');

  define('TEXT_PRODUCTS_QUANTITY_MAX_RETAIL_EDIT','0 = ̵¡1 = ɽ');

  define('TEXT_PRODUCTS_MIXED','Ǿ/ñ̥ߥå:');

  define('PRODUCTS_PRICE_IS_FREE_TEXT', 'ξʤ̵Ǥ');
  define('TEXT_PRODUCT_IS_FREE','̵:');
  define('TEXT_PRODUCTS_IS_FREE_PREVIEW','*̵ȥޡ줿');
  define('TEXT_PRODUCTS_IS_FREE_EDIT','*̵ȥޡ줿');

  define('TEXT_PRODUCT_IS_CALL','ʤ䤤碌:');
  define('TEXT_PRODUCTS_IS_CALL_PREVIEW','*ʤ䤤碌ȥޡ줿');
  define('TEXT_PRODUCTS_IS_CALL_EDIT','*ʤ䤤碌ȥޡ줿');

  define('TEXT_ATTRIBUTE_COPY_SKIPPING','<strong>°򥹥å </strong>');
  define('TEXT_ATTRIBUTE_COPY_INSERTING','<strong>°ʲ </strong>');
  define('TEXT_ATTRIBUTE_COPY_UPDATING','<strong>°ʲ鹹 </strong>');

// meta tags
  define('TEXT_META_TAG_TITLE_INCLUDES','ʸ񥿥ȥʡtitleǡˤλ');
//Mark What the Product\'s Meta Tag Title Should Include:</strong>
  define('TEXT_PRODUCTS_METATAGS_PRODUCTS_NAME_STATUS','<strong>̾:</strong>');
  define('TEXT_PRODUCTS_METATAGS_TITLE_STATUS','<strong>ȥ:</strong>');
  define('TEXT_PRODUCTS_METATAGS_MODEL_STATUS','<strong>ǥ:</strong>');
  define('TEXT_PRODUCTS_METATAGS_PRICE_STATUS','<strong>:</strong>');
  define('TEXT_PRODUCTS_METATAGS_TITLE_TAGLINE_STATUS','<strong>Ѥߥ饤:</strong>');
  define('TEXT_META_TAGS_TITLE','<strong>ȥ:</strong>');
  define('TEXT_META_TAGS_KEYWORDS','<strong>Meta(Keywords):</strong>');
  define('TEXT_META_TAGS_DESCRIPTION','<strong>Meta(Description):</strong>');
  define('TEXT_META_EXCLUDED', '<span class="alert">ӽƤޤ</span>');

?>
